@@ -1,4 +1,5 @@
-#' Find free energy minima in the fes object
+#' Find free energy minima in the fes object (generic function for 'metadynminer'
+#' and 'metadynminer3d')
 #'
 #' `fesminima` finds free energy minima on 1D or 2D free energy surface.
 #' The surface is divided by a 1D or 2D grid and minima are found for each
@@ -10,12 +11,29 @@
 #' @param nbins number of bins for each CV (default 8).
 #' @return minima object.
 #'
+#' @export fesminima
+fesminima<-function(inputfes, nbins) {
+  UseMethod("fesminima")
+}
+
+#' Find free energy minima in the fes object
+#'
+#' `fesminima.fes` finds free energy minima on 1D or 2D free energy surface.
+#' The surface is divided by a 1D or 2D grid and minima are found for each
+#' bin. Next the program determines whether the minimum of a bin is a local
+#' minimum of the whole free energy surface. Free energy minima are labeled
+#' constitutively by capital letters.
+#'
+#' @param inputfes fes object.
+#' @param nbins number of bins for each CV (default 8).
+#' @return minima object.
+#'
 #' @export
 #' @examples
 #' tfes<-fes(acealanme, imax=5000)
 #' minima<-fesminima(tfes)
 #' minima
-fesminima<-function(inputfes, nbins=8) {
+fesminima.fes<-function(inputfes, nbins=8) {
   fes<-inputfes$fes
   rows<-inputfes$rows
   rb <- rows/nbins
@@ -91,7 +109,8 @@ fesminima<-function(inputfes, nbins=8) {
   return(minima)
 }
 
-#' Creates one ad hoc free energy minimum for a fes object
+#' Creates one ad hoc free energy minimum for a fes object (generic function
+#' for 'metadynminer' and 'metadynminer3d')
 #'
 #' `oneminimum` creates an ad hoc free energy minimum on free energy surface.
 #' This can be used to calculate free energy surface evolution at arbitrary
@@ -100,6 +119,24 @@ fesminima<-function(inputfes, nbins=8) {
 #' @param inputfes fes object.
 #' @param cv1 the value of collective variable 1.
 #' @param cv2 the value of collective variable 2.
+#' @param cv3 the value of collective variable 3.
+#' @return minima object.
+#'
+#' @export oneminimum
+oneminimum<-function(inputfes, cv1, cv2, cv3) {
+  UseMethod("oneminimum")
+}
+
+#' Creates one ad hoc free energy minimum for a fes object
+#'
+#' `oneminimum.fes` creates an ad hoc free energy minimum on free energy surface.
+#' This can be used to calculate free energy surface evolution at arbitrary
+#' point of free energy surface.
+#'
+#' @param inputfes fes object.
+#' @param cv1 the value of collective variable 1.
+#' @param cv2 the value of collective variable 2.
+#' @param cv3 the value of collective variable 3.
 #' @return minima object.
 #'
 #' @export
@@ -108,7 +145,7 @@ fesminima<-function(inputfes, nbins=8) {
 #' minima<-fesminima(tfes)
 #' minima<-minima+oneminimum(tfes, cv1=0, cv2=0)
 #' minima
-oneminimum<-function(inputfes, cv1, cv2) {
+oneminimum.fes<-function(inputfes, cv1, cv2, cv3) {
   fes<-inputfes$fes
   rows<-inputfes$rows
   per<-inputfes$per
@@ -359,11 +396,26 @@ plot.minima <- function(x, plottype="both",
   }
 }
 
+#' Calculate free energy profile for minima object (generic function for 'metadynminer'
+#' and 'metadynminer3d')
+#'
+#' `feprof` calculates free energy profiles for free energy minima. It finds the global minimum
+#' at the `imax` and calculates the evolution of free energies of a local vs. the global free energy
+#' minimum. The free energy of the global minimum is constant (zero).
+#'
+#' @param minims minima object.
+#' @param imax index of a hill from which summation stops (default the rest of hills).
+#'
+#' @export
+feprof <- function(minims, imax) {
+  UseMethod("feprof")
+}
+
 #' Calculate free energy profile for minima object
 #'
-#' `feprof` calculates free energy profiles for free energy minima. It finds the global minimum at the
-#' `imax` and calculates the evolution of free energies of a local vs. the global free energy minimum.
-#' The free energy of the global minimum is constant (zero).
+#' `feprof.minima` calculates free energy profiles for free energy minima. It finds the global minimum
+#' at the `imax` and calculates the evolution of free energies of a local vs. the global free energy
+#' minimum. The free energy of the global minimum is constant (zero).
 #'
 #' @param minims minima object.
 #' @param imax index of a hill from which summation stops (default the rest of hills).
@@ -374,7 +426,7 @@ plot.minima <- function(x, plottype="both",
 #' minima<-fesminima(tfes)
 #' prof<-feprof(minima)
 #' prof
-feprof <- function(minims, imax=NULL) {
+feprof.minima <- function(minims, imax=NULL) {
   fes<-minims$fes
   rows<-minims$rows
   mins<-minims$minima
